---
title: 初始化
sidebar_position: 40
---

# 初始化




在使用 SDK 其它功能前，必须先进行初始化。本文中将详细说明初始化的方法。

## 注意事项

- 必须在应用生命周期内调用初始化方法，只需要调用一次。

## 准备 App Key

您必须拥有正确的 App Key，才能进行初始化。

您可以[登录融云控制台]，从**服务管理**页面，查看您已创建的各个应用的 App Key。

如果您拥有多个应用，请注意选择应用名称（下图中标号 1）。另外，融云的每个应用都提供用于隔离生产和开发环境的两套独立 App Key / Secret。在获取应用的 App Key 时，请注意区分环境（**生产** / **开发**，下图中标号 2）。

>- 如果您并非应用创建者，我们建议在获取 App Key 时确认页面上显示的**数据中心**是否符合预期。
>- 如果您尚未向融云申请应用上线，仅可使用开发环境。

![appkey](./assets/appkey.png)

## 初始化之前

部分配置必须在初始化之前完成，否则 SDK 功能无法正常工作。

- **开通音视频服务**：音视频服务需要手动开通。请根据应用的具体业务类型，开通对应的音视频服务。详细说明请参见[开通音视频服务]。
- **海外数据中心**：因为音视频业务依赖即时通讯业务 IMLib 提供信令通道，如果您的应用使用海外数据中心，必须在初始化之前修改 IMLib SDK 默认连接的服务地址为海外数据中心地址。否则 SDK 默认连接中国国内数据中心服务地址。详细说明请参见[配置海外数据中心服务地址]。

## 权限配置

iOS 需要在 Info.plist 中加入相机和麦克风的使用描述

```html
<key>NSCameraUsageDescription</key>
<string>使用相机</string>
<key>NSMicrophoneUsageDescription</key>
<string>使用麦克风</string>
```

Android 需要在 AndroidManifest.xml 文件中声明相机、麦克风和网络的使用权限

```xml
<uses-permission android:name="android.permission.CAMERA" />
<uses-permission android:name="android.permission.MODIFY_AUDIO_SETTINGS" />
<uses-permission android:name="android.permission.RECORD_AUDIO" />
<uses-permission android:name="android.permission.INTERNET" />
```

## 使用 App Key 初始化

音视频用户之间的信令传输依赖于融云的即时通信（IM）服务，所以要先初始化 IM SDK。如果不换 AppKey，在整个应用生命周期中，初始化一次即可。建议调用位置放在 `main()` 方法内，或在音视频功能模块的加载位置处。获取 IM 引擎实例后，需要先调用 `connect` 方法与 IM 服务建立好 TCP 长连接。建议在功能模块的加载位置处调用，之后再进行音视频业务。当模块退出后调用 `disconnect` 或 `logout` 断开该连接。

```dart
void main() {
    /// IMLib 初始化
    RCIMIWEngineOptions options = RCIMIWEngineOptions.create();
    RCIMIWEngine imEngine = await RCIMIWEngine.create(appKey, options);
    RCIMIWConnectCallback? callback = RCIMIWConnectCallback(onDatabaseOpened: (int? code) {
    //...
    }, onConnected: (int? code, String? userId) {
    //...
    });

    int? ret = await imEngine?.connect(token, timeout, callback:callback);
}
```

:::tip

 如需详细了解 IM SDK 初始化方法和具体配置，请转至 [IM SDK 文档](/flutter-imlib/init)。
:::


## 创建 RTC 引擎

在成功连接 IM 服务之后，您可以通过以下代码，创建 RTC 引擎。

```dart
engine = await RCRTCEngine.create();
```

或者通过以下方式传递配置项创建引擎。详细说明请参见[引擎配置]。

```dart
RCRTCEngineSetup setup = RCRTCEngineSetup.create();
engine = await RCRTCEngine.create(setup);
```

<!-- 链接区域 -->
[登录融云控制台]: https://console.rongcloud.cn/agile/formwork/app/appService/mAYKybm9ubTOKnmi2CRjkA
[配置海外数据中心服务地址]: https://help.rongcloud.cn/t/topic/1069
[开通音视频服务]: https://help.rongcloud.cn/t/topic/1022
[引擎配置]: ./engine-setup


